;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x4aebb8f75eb544a8f8fd753a72e96ec9 . "./code.cg2js/cg-common-control.fasl")
(#x4f6730fee14f5c82d08acdbdf18f5f61 . "./code.cg2js/cg-header-control.fasl")
(#x7f12dd9573898be57da4d0c13592244e . "./code.cg2js/cg-clipboard-stack.fasl")
(#xec0d1f008e441ba0b4d9b5999f630d43 . "./code.cg2js/cg-yes-no-string.fasl")
(#xfb7936957268c0cefcd431b7d4d01e0b . "./code.cg2js/cg-clipboard.fasl")
(#xf5fc8f3d819c2aaaff79a938fb4365dd . "./code.cg2js/cg-dde-utils.fasl")
(#x37911d0d5e8f603cf1b70cf92596da36 . "./code.cg2js/cg-editable-text.fasl")
(#xfbb2abc3e9f075c6d2c8cf01ae9f5b41 . "./code.cg2js/cg-text-or-combo.fasl")
(#xa623778bd72ff5da7df7210a82b5d34b . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x88d59df9edc3101e7ebfa93b7a9495bb . "./code.cg2js/cg-graphics-context.fasl")
(#x9cc5393f34a4897cd13cdf9085037dd4 . "./code.cg2js/cg-choose-printer.fasl")
(#xe9a8b58c66f78ba4a52474e5afc8d37a . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x2d8cc6282f6ee7c33e1e501bd61db373 . "./code.cg2js/cg-edit-in-place.fasl")
(#xfc686b021f05f798e61600039beaff56 . "./code.cg2js/cg-split-bar.fasl")
(#xdc997f02d6d26e96b3400d503d19599e . "./code.cg2js/cg-timer.fasl")
(#xc732fca7536ba4b5c96e8eecb001c9d2 . "./code.cg2js/cg-progress-indicator.fasl")
(#x486322a3407e1b3c42dc4fee582d8cff . "./code.cg2js/cg-object-editor.fasl")
(#x98dabe6742742c2338c81265e4692fa5 . "./code.cg2js/cg-fill-texture.fasl")
(#x025e4dde68aef7da6a43ae059188c167 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x6d504e04b965cefae0b69403bae93dea . "./code.cg2js/cg-os-window.fasl")
(#xcb195ddcab5291b6fee9239e8b7a19f0 . "./code.cg2js/cg-color-dialog.fasl")
(#x0097276ad60ab1671247f0fcdec1cf9c . "./code.cg2js/cg-combo-box.fasl")
(#xde9249149b2a15c843da6a0727b96ecd . "./code.cg2js/cg-directory-dialog.fasl")
(#x7c6cbd0a26c9f44076da4af32d827229 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xd4e1808ad22bdabaed4c9a0596645e86 . "./code.cg2js/cg-tooltip.fasl")
(#xff0796d19b8af88ba1e8f741ba78967a . "./code.cg2js/cg-lettered-menu.fasl")
(#x48da48075cd43531a27efdff02d11582 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xb8ec6d56332b42a41585d92d4f0e8d7e . "./code.cg2js/cg-pixmap.fasl")
(#x17f4aab4afcec428826be909d0c6dcff . "./code.cg2js/cg.fasl")
(#xc19f700cf4c9e7cf7e261d4f9ea38c3f . "./code.cg2js/cg-class-slot-grid.fasl")
(#xd852a08c88cc573dcc000308caa4cf57 . "./code.cg2js/cg-template-string.fasl")
(#x47218c793ea208665c330fbaeb7dcab3 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#xe4d4a94def6c3ac4de542260330ed399 . "./code.cg2js/cg-check-box.fasl")
(#xf4967657ea7c5fa919edec856d9e24f6 . "./code.cg2js/cg-toggling-widget.fasl")
(#x3e042c7c120aee6a3d8d7317c3afaa08 . "./code.cg2js/cg-radio-button.fasl")
(#xbda861d599abff8039a36feecbf4eed6 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x59385f54544a704a82f619019c2a9ec9 . "./code.cg2js/cg-scaling-stream.fasl")
(#xf5bbf659b651ece8d82e3fe022e40020 . "./code.cg2js/cg-multi-picture-button.fasl")
(#xa0196625233c86b47dd618a51cd4aa37 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xf5b42191968bd2ec637bac4431128137 . "./code.cg2js/cg-grid-widget.fasl")
(#xf23b6b136c810d00dbba6c364cad7a81 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x73ae58254e448833f23c16af4a079e67 . "./code.cg2js/cg-item-list.fasl")
(#x69ecb1d9787b2b768ba0570bd26720b9 . "./code.cg2js/cg-paren-matching.fasl")
(#xda516f3d3f6311e92e2103fcebf284c6 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xaa8aa288e4194652e13fb83cc0428c8a . "./code.cg2js/cg-html-dialog.fasl")
(#xa2a0e547061a5b6ab6d68d7af6eda93c . "./code.cg2js/cg-pixmap-widget.fasl")
(#xea258d20c58dc1eefaa5b6b6c0ee44b5 . "./code.cg2js/cg-project-window.fasl")
(#x2e6e5da2b7ccc85de7115ae2be4b1392 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x868f7a9abe7674dd3e7a5b1058db4b6a . "./code.cg2js/cg-toolbar.fasl")
(#xc48153853d7b0ee86fa5ed5d68b42610 . "./code.cg2js/cg-caret.fasl")
(#x26b4ec5aa30f324ad664b35234f22182 . "./code.cg2js/cg-scroll-bar.fasl")
(#x860b79938b2afc9404d8c30c6c049ed0 . "./code.cg2js/cg-web-browser.fasl")
(#x6708c5bbd41b2ea3c53ae6c43aa27c67 . "./code.cg2js/cg-dropping-outline.fasl")
(#x73d49be1a9fed9176626580a9cb680de . "./code.cg2js/cg-font-dialog.fasl")
(#x01ffd7a90ec3d7ef3494f961708c0242 . "./code.cg2js/cg-icon-pixmap.fasl")
(#xb8759a18f4f966b2e242c365eaa89b5c . "./code.cg2js/cg-yes-no-list.fasl")
(#x3bfca4b46016d09873d96fdcbf69b695 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x110555044444ac19c5be1469c2d2c565 . "./code.cg2js/cg-lamp.fasl")
(#x89e645cec8f0f352d4efd4b4d0760b15 . "./code.cg2js/cg-drawable.fasl")
(#xc743192c7aab621847ecf990781027a7 . "./code.cg2js/cg-choice-list.fasl")
(#x4446de012b1e15f56a630ab3ed00f876 . "./code.cg2js/cg-curve.fasl")
(#x984522dd251c8cf2b155af6acfbdeea5 . "./code.cg2js/cg-base.fasl")
(#x9190471428083c61312c6acad5b7fb0f . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xb9ca5e90350a7d93be44559358102917 . "./code.cg2js/cg-printing.fasl")
(#x8bf6c75b6a192062f61dd2f9110b1704 . "./code.cg2js/cg-chart-or-plot.fasl")
(#x5e2a49c3a9f67f7e4b328cf68dd6bafe . "./code.cg2js/cg-hotspot.fasl")
(#x8ddb343e19a75536267c6e04b20a5b5e . "./code.cg2js/cg-object-editor-layout.fasl")
(#xb577619b57ad613a7d6c35d9dddad6d2 . "./code.cg2js/cg-utility-dialog.fasl")
(#x42db61119e304cf05a38a6f27bcdefd7 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x2582b9f575c78f0989c7dec89a4990ee . "./code.cg2js/cg-comtab.fasl")
(#xe2505937c48523e73e53c768689841b6 . "./code.cg2js/cg-os-widget.fasl")
(#x497ce51e3380df49caa5fb708e743761 . "./code.cg2js/cg-icon.fasl")
(#x32d9646ce4e2f26b80e5cb1407e80454 . "./code.cg2js/cg-dev.fasl")
(#x479df51a7fb35b32e7d6486354e33c76 . "./code.cg2js/cg-calendar.fasl")
(#x3f5ff1a124f43821df3da292d07d2845 . "./code.cg2js/cg-group-box.fasl")
(#x0c5a314d33b5ee4c6e63b884d995688f . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x19ae12c276384da21111e730cbaa5e4a . "./code.cg2js/cg-bitmap-pane.fasl")
(#xf8126b39f8f5c1c6d53dd28b766a185a . "./code.cg2js/cg-drag-and-drop.fasl")
(#xd881df27012f29c9452ce28cc6a904cf . "./code.cg2js/cg-nodes.fasl")
(#xaf56984f78f27848dfdd44785e0755ad . "./code.cg2js/cg-intersect.fasl")
(#xf11ba7ac899cf11d8dc3c485326e354c . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xa77cbccde11639a430bb3dafa091a9f9 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x318ac9e01f3fcd0c2788a5b18bbe8313 . "./code.cg2js/cg-class-support.fasl")
(#x5a0364f5369f5a8e4a55d705fbc61a1b . "./code.cg2js/cg-dialog-item.fasl")
(#xb1f4c7a76641da07514193444b909284 . "./code.cg2js/cg-plot-widget.fasl")
(#xe473db98ecb77a67ca68f320e8d00286 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x8ba189e238b2bcb3529e53724e3d9bb1 . "./code.cg2js/cg-up-down-control.fasl")
(#xc0bd386d7a70539c6fc5c06579489776 . "./code.cg2js/cg-rich-edit.fasl")
(#xf5fed61f1cad317b2bfa2c401818a497 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xab6248ac30358d5847ab5caea1455593 . "./code.cg2js/cg-status-bar.fasl")
(#x536e6d835c2a99ce697c3ef122bf1021 . "./code.cg2js/cg-class-grid.fasl")
(#xfee5be35b562cea84fdd491e13fb2c3d . "./code.cg2js/cg-wrap-string.fasl")
(#x5ebd3a92668185b7e28519af20336566 . "./code.cg2js/cg-layout.fasl")
(#xfe5c648cea544313d5efe02d48f8e8b5 . "./code.cg2js/cg-lisp-widget.fasl")
(#x7a037fdd4018a543ebd41e84bef49248 . "./code.cg2js/cg-button.fasl")
(#xe36030215f29f2456d80a092b7734a2d . "./code.cg2js/cg-string-dialog.fasl")
(#x435271929b4a2d142151794608b35f7b . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x256f2eab4cb4fae51a8aa69a1a380366 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xe539b1a36c9f4c5077f0cb834da52dd4 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x5d7f5eab4f9b68901a06963b64d024ff . "./code.cg2js/cg-static-text.fasl")
(#x26b2acdbd260f63c6ec2c2eca54ffd0e . "./code.cg2js/cg-outline.fasl")
(#x99a0a3a5c986da0c62e57dd2dd66cadf . "./code.cg2js/cg-gesture-emulation.fasl")
(#x88f879aa7d2f289c5d60f58d08c08b43 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x3407554b9c9ab3c9916c33c771870008 . "./code.cg2js/cg-picture-widget.fasl")
(#xdb7e5de9a0829840ad0c8f77e4270f6f . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x29da14447f4ac9dfa1bb66c6376cceed . "./code.cg2js/cg-chart-widget.fasl")
(#x5901cbaca94a86e307b3c1171b3549a6 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xa1c75c17c56e4d452be28d25909fac2b . "./code.cg2js/cg-lisp-text.fasl")
(#x2ecaa326e7f5c4a317b8999bcc581885 . "./code.cg2js/cg-palette.fasl")
(#x52410a4cd00ecff91bd84219a029611c . "./code.cg2js/cg-property.fasl")
(#x10a8efdbf04ac4d1b84c8b15e3890c15 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xbf4ea802d5dc40950ba8a7689b6c7597 . "./code.cg2js/cg-file-dialog.fasl")
(#x165cb84452ccda18e4031a886a7d374b . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x3ca23f31ed8734d8a0f7291f4ae42ec2 . "./code.cg2js/cg-get-pixmap.fasl")
(#x261658ef40467d523244a675e5d2ce0f . "./code.cg2js/cg-tray.fasl")
(#x21084de8aef10835eb7179b7bb046b6c . "./code.cg2js/cg-acache.fasl")
(#x91c5ba0a25f845c2fc48b1f9b8820ab5 . "./code.cg2js/cg-message-dialog.fasl")
(#x08095dcd93a707bc9aa15a30535c664c . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x1175d6c75125238eeda39bc0fadc0166 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x7899bd1e1bb94f071ef46d1865e44cdd . "./code.cg2js/cg-tab-control.fasl")
(#xbd8dc9a27860fd11af97128d99b8e973 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xb5a8fb6e23162183994db69de9185cb3 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x2b63d75277675de36e3fa04503256e9c . "./code.cg2js/cg-find-string-dialog.fasl")
(#xc90a51966ba6b22f769ae6074a7e63ad . "./code.cg2js/cg-menu.fasl")
(#x7360222c0ad250bf711b930f96783ac1 . "./code.cg2js/cg-get-position.fasl")
(#x6cc05a26c0145a35933684b3e7d320db . "./code.cg2js/cg-trackbar.fasl")
(#x51cdc6f52eaa4e730baf46bbe6eb5d46 . "./code.cg2js/cg-selected-object.fasl")
(#x1b560341fe3b363d55c1a3dc8e9773d6 . "./code.cg2js/cg-list-view.fasl")
(#xef09f80bba2166c17e8b3374f4974509 . "./code.cg2js/cg-html-widget.fasl")
(#xa69e9f1cfc23ff3918bc8716990f7ddd . "./code.cg2js/cg-sample-file-menu.fasl")
(#xaf9581da4d861daa184131b2bb32501d . "./code.cg2js/cg-text-widget.fasl")
(#x393041530757368e50ade7603f8fddb6 . "./code.idejs/ide-base.fasl")
(#x48a5ff42b49c744aa6cff3f1be52ae85 . "./code.idejs/ide-process-browser.fasl")
(#xaa5bc630cf3c51196049798f413dbb59 . "./code.idejs/ide-patch-dialog.fasl")
(#x4be360b3ee2d7d1a65f74154ddf21adc . "./code.idejs/ide-keyshort.fasl")
(#xede980907e792018aa519923961c2e7e . "./code.idejs/ide-window-list.fasl")
(#x0866cd465674be5a385aeb282510865c . "./code.idejs/ide.fasl")
(#x906a3cf5dd182197207476606368133b . "./code.idejs/ide-editor.fasl")
(#x7dc929a761fd49f5f32fbd66f08724d1 . "./code.idejs/ide-clipboard.fasl")
(#xbb40fbe0e75797ad5a85cab13966adf6 . "./code.idejs/ide-trace.fasl")
(#x6a646ce59195ece0d9c0f32801376f8e . "./code.idejs/ide-class-browser.fasl")
(#x9699e02ff2bddbf5179a05f33c1a7309 . "./code.idejs/ide-grapher.fasl")
(#x6dec6166c68348dbc24f4dfe83eb2061 . "./code.idejs/ide-apropos.fasl")
(#x2cc5eecaf3e3e6493f9c05eeb0a52a97 . "./code.idejs/ide-navigator.fasl")
(#x291fb51841d042e78223ad66feebbd98 . "./code.idejs/ide-find-definitions.fasl")
(#x6fd17d6c2f1d9058b9a60ec2a2e29890 . "./code.idejs/ide-project.fasl")
(#x7cb6585aecc935088268a6e9693890cf . "./code.idejs/ide-class-grapher.fasl")
(#x5afb39a9ca2dba48dda765f3a2d1171e . "./code.idejs/ide-acache.fasl")
(#xf7a4ee4bc16bd277ad36ca502bdbb675 . "./code.idejs/ide-find-in-files.fasl")
(#xbf64c2b80aa5df1ba7cdeca19d2d51da . "./code.idejs/ide-inspector.fasl")
(#xd4e32f2d3b060761d16c8f36e37d6ea6 . "./code.idejs/ide-intro.fasl")
(#xc1f393b04ef86cf8329563936a4b808c . "./code.idejs/ide-package-list.fasl")
(#xb389418d16e1a40e96878d2f33455cc7 . "./code.idejs/ide-dev.fasl")
(#xe799d49c6bef787dbf6f5c657b5a5397 . "./code.idejs/ide-form.fasl")
(#x785b009207cd19fe54c93fc535e484ec . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
